==> hibernate-search-mapper-orm-outbox-polling-7.2.2.Final.jar: module-info.java <==
/* synthetic */ module org.hibernate.search.mapper.orm.outboxpolling {
    requires jakarta.xml.bind;
    requires jakarta.persistence;
    requires org.apache.avro;
    /* transitive */ requires org.hibernate.orm.core;
    /* transitive */ requires org.hibernate.search.engine;
    /* transitive */ requires org.hibernate.search.mapper.orm;
    /* transitive */ requires org.hibernate.search.mapper.pojo;
    /* transitive */ requires org.hibernate.search.util.common;
    requires org.jboss.logging;

    exports org.hibernate.search.mapper.orm.outboxpolling;
    exports org.hibernate.search.mapper.orm.outboxpolling.avro.generated.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.outboxpolling.avro.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.outboxpolling.cfg;
    exports org.hibernate.search.mapper.orm.outboxpolling.cfg.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.outboxpolling.cfg.spi;
    exports org.hibernate.search.mapper.orm.outboxpolling.cluster.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.outboxpolling.event.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.outboxpolling.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.outboxpolling.logging.impl to org.jboss.logging, org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.outboxpolling.mapping;
    exports org.hibernate.search.mapper.orm.outboxpolling.mapping.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.outboxpolling.mapping.spi;

    opens org.hibernate.search.mapper.orm.outboxpolling.avro.generated.impl to org.apache.avro;
    opens org.hibernate.search.mapper.orm.outboxpolling.cluster.impl to org.hibernate.orm.core, net.bytebuddy;
    opens org.hibernate.search.mapper.orm.outboxpolling.event.impl to org.hibernate.orm.core, net.bytebuddy;

    provides BeanConfigurer with OutboxPollingBeanConfigurer;

}

==> hibernate-search-mapper-orm-outbox-polling-8.1.2.Final.jar: module-info.java <==
/* synthetic */ module org.hibernate.search.mapper.orm.outboxpolling {
    requires jakarta.xml.bind;
    requires jakarta.persistence;
    requires org.apache.avro;
    /* transitive */ requires org.hibernate.models;
    /* transitive */ requires org.hibernate.orm.core;
    /* transitive */ requires org.hibernate.search.engine;
    /* transitive */ requires org.hibernate.search.mapper.orm;
    /* transitive */ requires org.hibernate.search.mapper.pojo;
    /* transitive */ requires org.hibernate.search.util.common;
    requires org.jboss.logging;

    exports org.hibernate.search.mapper.orm.outboxpolling;
    exports org.hibernate.search.mapper.orm.outboxpolling.avro.generated.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.outboxpolling.avro.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.outboxpolling.cfg;
    exports org.hibernate.search.mapper.orm.outboxpolling.cfg.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.outboxpolling.cfg.spi;
    exports org.hibernate.search.mapper.orm.outboxpolling.cluster.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.outboxpolling.event.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.outboxpolling.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.outboxpolling.logging.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.outboxpolling.mapping;
    exports org.hibernate.search.mapper.orm.outboxpolling.mapping.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.outboxpolling.mapping.spi;

    opens org.hibernate.search.mapper.orm.outboxpolling.avro.generated.impl to org.apache.avro;
    opens org.hibernate.search.mapper.orm.outboxpolling.cluster.impl to org.hibernate.orm.core, net.bytebuddy;
    opens org.hibernate.search.mapper.orm.outboxpolling.event.impl to org.hibernate.orm.core, net.bytebuddy;

    provides BeanConfigurer with OutboxPollingBeanConfigurer;

}
